<div class="md:h-[827px] h-auto flex flex-col items-center md:flex-row justify-center md:gap-x-[100px] py-[100px] md:py-[100px] px-4 md:px-0 bg-cover bg-no-repeat bg-right md:bg-center"
    style="background-image: url('<?php echo e(asset('./images/background/bg-sambutan.png')); ?>');">
    <div class="flex justify-center md:justify-start w-full md:w-auto flex-col items-center">
    <img src="<?php echo e(asset('./images/sambutan/sambutan.png')); ?>" data-aos="fade-up"
        class="h-auto md:w-[1000px] w-[300px] md:h-[500px] max-w-[450px]" style="border-radius:25px;" alt="<?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>">
    <p style="padding-top: 20px; font-size: 14px; color: #fff; text-align: center; font-family: 'Poppins', sans-serif;">
        <!-- <b>Dendi Afrizal, S.AB., M.Ak, </b> -->
    </p>
</div>
    <div class="flex flex-col md:items-start justify-center items-center w-full md:w-[40%] w-[100%] mt-4 md:mt-0"
        data-aos="fade-up">
        <?php if (isset($component)) { $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSection::class, ['subtext' => ' SAMBUTAN KETUA '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','subtextColor' => '#fff','title' => '','titleColor' => '#fff']); ?>
<?php $component->withName('header-section'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe)): ?>
<?php $component = $__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe; ?>
<?php unset($__componentOriginal6a781ab4f935d26ee180d4f6257728a5529effbe); ?>
<?php endif; ?>
        <p class="text-justify font-dmsans mb-4 font-inter text-sm md:text-base  normal-case w-[80%]" style="color:#fff" >
        Selamat datang di Program Studi DIII Farmasi Akademi Farmasi Imam Bonjol Bukittinggi (AKFAR IB) <br><br>
Kami bangga menjadi salah satu bagian dari pendidikan vokasi dalam bidang farmasi di Indonesia. Sebagai salah satu institusi pendidikan tinggi yang terus berkembang kami berkomitmen untuk melaksanakan pendidikan yang bermutu dan berorientasi pada kebutuhan dunia kerja. Kurikulum kami dirancang secara dinamis dan diperbarui secara berkala agar selalu selaras dengan perkembangan ilmu pengetahuan dan tuntutan kebutuhan dunia kesehatan.
Dengan sistem pembelajaran berbasis kompetensi dan didukung oleh tenaga pengajar profesional, kami memastikan bahwa lulusan kami memiliki keterampilan yang sesuai dengan standar yang ditetapkan. Hal ini dibuktikan dari jumlah lulusan kami yang telah mendapatkan pekerjaan dan waktu tunggu dalam mendapatkan pekerjaan. Lulusan Prodi DIII Farmasi AKFAR IB telah bekerja di berbagai sektor, baik di rumah sakit, puskesmas, klinik, apotek, maupun instansi pemerintah dan swasta.
Sebagai bukti komitmen kami terhadap kualitas, Prodi DIII Farmasi AKFAR IB telah meraih hasil terbaik dalam ujian kompetensi nasional selama dua tahun berturut-turut, dengan tingkat kelulusan 100%. Prestasi ini menjadi cerminan dari mutu pendidikan dan kesiapan lulusan kami dalam menghadapi dunia kerja.
Kami mengundang Anda untuk bergabung bersama kami dan menjadi bagian dari tenaga farmasi profesional yang berkompeten dan siap bersaing di era global.

       </p>
        
<a href="/sejarah-singkat" class="bg-yellow-400 hover:bg-primary font-medium py-2 px-3 rounded-md text-sm transition-all  text-center text-white">
    BACA SELENGKAPNYA
</a>
    </div>
</div>
<?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/WEB/resources/views/Frontend/landingpage/sambutan-section.blade.php ENDPATH**/ ?>