@section('title', 'VisiMisi')

@extends('Frontend.Layouts.app2')
@section('content')
    <br><br>
    <x-header-section-page title="Visi Misi {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}"
        breadcrumb-home="Home" breadcrumb-current="Visi Misi" />

    <!-- Content Section -->
    <div class=" py-10 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-16 space-y-12">
            <!-- Visi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Visi</h2>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans">
                    🎯 Menjadi perguruan tinggi ekonomi islam yang unggul dan berdaya saing tinggi serta memiliki jiwa
                    enterpreneur dengan mengedepankan nilai-nilai Islam.
                </p>
            </div>

            <!-- Misi -->
            <div data-aos="fade-up" class="bg-white shadow-xl shadow rounded-lg p-6">
                <h2 data-aos="fade-up" class="text-xl font-poppins font-semibold text-primary mb-3">Misi</h2>
                <ul data-aos="fade-up" class="list-disc pl-5 space-y-3 text-gray-700 font-dmsans">
                    <li>
                        Menyelenggarakan pendidikan dan pengajaran yang berorientasi pada dunia kerja dan enterpreneur.

                    </li>
                    <li>
                        Menyelenggarakan kegiatan penelitian yang terintegasi dengan pembelajaran untuk menghasilkan karya
                        ilmiah bereputasi.
                    </li>
                    <li>
                        Menyelenggarakan program kegiatan pengabdian kepada masyarakat untuk kesejahteraan masyarakat dan
                        pengembangan kewirausahaan.
                    </li>
                    <li>
                        Menyelenggarakan kerjasama dan kemitraan dengan berbagai lembaga pemerintah dan swasta, serta
                        perusahaan yang ada di kawasan industri Karawang dan sekitarnya.
                    </li>

                </ul>
            </div>

            <!-- Call to Action -->
            <div data-aos="fade-up" class="text-center shadow-xl">
                <div data-aos="fade-up" class="bg-accent py-8 rounded-lg" style="color:#fff">
                    <h2 data-aos="fade-up" class="text-xl font-poppins font-bold  mb-3">Bergabunglah dengan
                        {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}
                    </h2>
                    <p data-aos="fade-up" class=" font-dmsans mb-5">Wujudkan impianmu dan raih masa depan cerah bersama
                        {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}</p>
                    <a href="/pendaftaran" data-aos="fade-up"
                        class="x-button font-poppins font-medium py-2 px-6 rounded-full shadow-md hover:bg-gray-100 transition">
                        Daftar Sekarang
                    </a>
                </div>
            </div>
        </div>
    </div>
@endsection
