<?php $__env->startSection('title', 'Sejarah'); ?>


<?php $__env->startSection('content'); ?>
<br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Sejarah  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Sejarah Singkat']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p class="text-justify" style="font-size: 14px;">
            
            Yayasan Pondok Pesantren Al Kamal (YPP) didirikan di Jakarta pada tahun 1987 oleh tokoh-tokoh dan kader Cendekiawan Muslim, Ulama, Tokoh Pemerintah dan Pemuka Masyarakat. Upaya yang dilakukan adalah ikut berperan serta dalam mensukseskan pembangunan nasional di bidang pendidikan dan pelayanan kesehatan bagi umat di Indonesia.
                
            </p>
            <p class="text-justify" style="font-size: 14px;">
            
            YPP Al Kamal Jakarta bercita-cita untuk mencetak muslim yang berbudi luhur, Berpengetahuan luas, berwawasan kebangsaan, mandiri serta terampil, serta mempunyai kekuatan antara ilmu Agama dan penguasaan teknologi (IMTAQ dan IPTEK).
            </p>
            <p class="text-justify" style="font-size: 14px;">
            
            Dalam rangka mewujudkan keinginan itu Yayasan Pondok Pesantren Al-Kamal Jakarta tergugah untuk turut berperan serta secara aktif membantu pemerintah dengan membentuk unit-unit kegiatan sebagai berikut: TK Al-Kamal Jakarta, SD Al-Kamal Jakarta, SMP Al-Kamal Jakarta, SMA dan SMK Al-Kamal Jakarta, Institut Sains dan Teknologi Al-Kamal (ISTA), dan Rumah Sakit Puri Mandiri Kedoya.

            </p>
            <p class="text-justify" style="font-size: 14px;">
            
            Pengembangan fisik serta program pendidikan, penelitian, dan pengabdian kepada masyarakat sedang digalakan. Untuk melengkapi hal tersebut diatas tersedia beberapa gedung sedang dan akan di bangun dalam rangka pengembangan Institut Sains dan Teknologi Al-Kamal. Pola Ilmiah Pokok Institut Sains dan Teknologi Al-Kamal adalah Lingkungan Hidup.
            
            </p>            
        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
                </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
            Bergabunglah bersama  <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?> dan Bangun Wawasan, Bentuk Karakter, Jadilah Pembawa Perubahan!
        </p>
            <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/WEB/resources/views/Frontend/sejarah.blade.php ENDPATH**/ ?>