

<?php $__env->startSection('title', 'Data Biaya Kuliah'); ?>

<?php $__env->startSection('content'); ?>
<div class="page-content">
    <nav class="page-breadcrumb">
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="<?php echo e(route('dashboard')); ?>">Dashboard</a></li>
            <li class="breadcrumb-item active" aria-current="page">Data Biaya Kuliah</li>
        </ol>
    </nav>

    <div class="row">
        <div class="col-md-12 grid-margin stretch-card">
            <div class="card">
                <div class="card-body">
                    <div class="panel-heading mb-3 d-flex justify-content-between align-items-center">
                        <h1 class="card-title">Data Biaya Kuliah</h1>
                        <a href="<?php echo e(route('biaya.create')); ?>" class="btn btn-primary">
                            <i class="fa fa-plus fa-fw"></i> Tambah Biaya
                        </a>
                    </div>
                    <form method="GET" action="<?php echo e(route('biaya.index')); ?>" class="mb-3">
                            
                            <div class="d-flex flex-wrap align-items-center gap-2">
                                <input type="text" name="search" class="form-control w-auto" placeholder="Cari Jurusan" value="<?php echo e(request('search')); ?>">
                                <button type="submit" class="btn btn-primary btn-sm mt-2 mt-md-0">
                                    <i class="fa fa-search"></i> Cari
                                </button>
                            </div>
                    </form>

                    <?php if(session('message')): ?>
                        <div class="alert alert-<?php echo e(session('alert-type', 'success')); ?> alert-dismissible fade show" role="alert">
                            <?php echo e(session('message')); ?>

                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                    <?php endif; ?>

                    <div class="table-responsive">
                        <table class="table table-bordered table-striped">
                            <thead>
                                <tr>
                                    <th>No</th>
                                    <th>Kategori</th>
                                    <th>Jurusan</th>
                                    <th>Biaya Awal</th>
                                    <th>Biaya SPP</th>
                                    <th>Deskripsi</th>
                                    <th>Aksi</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php $__empty_1 = true; $__currentLoopData = $biayas; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $biaya): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
                                    <tr>
                                        <td><?php echo e(($biayas->currentPage() - 1) * $biayas->perPage() + $index + 1); ?></td>
                                        <td><?php echo e($biaya->kategori); ?></td>
                                        <td><?php echo e($biaya->jurusan); ?></td>
                                        <td>Rp <?php echo e(number_format($biaya->biaya_awal, 0, ',', '.')); ?></td>
                                        <td>Rp <?php echo e(number_format($biaya->biaya_spp, 0, ',', '.')); ?></td>
                                        <td><?php echo \Illuminate\Support\Str::limit(strip_tags($biaya->deskripsi), 100, '...'); ?></td>
                                        <td>
                                            <div class="d-flex flex-wrap gap-2">
                                                <a href="<?php echo e(route('biaya.edit', $biaya->biaya_id)); ?>" class="btn btn-warning btn-sm">Edit</a>
                                                <form action="<?php echo e(route('biaya.destroy', $biaya->biaya_id)); ?>" method="POST" onsubmit="return confirm('Yakin ingin menghapus data ini?')" style="display:inline-block;">
                                                    <?php echo csrf_field(); ?>
                                                    <?php echo method_field('DELETE'); ?>
                                                    <button type="submit" class="btn btn-danger btn-sm">Hapus</button>
                                                </form>
                                            </div>
                                        </td>
                                    </tr>
                                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>
                                    <tr>
                                        <td colspan="7" class="text-center">Tidak ada data biaya</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>

                    <?php if($biayas instanceof \Illuminate\Pagination\LengthAwarePaginator): ?>
                        <div class="mt-3">
                            <?php echo e($biayas->links('vendor.pagination.simple-bootstrap-5')); ?>

                        </div>
                    <?php endif; ?>

                </div>
            </div>
        </div>
    </div>
</div>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('dashboard.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Ijo-Kuning/resources/views/admin/biaya/index.blade.php ENDPATH**/ ?>