<?php $__env->startSection('title', 'Struktur'); ?>


<?php $__env->startSection('content'); ?>
    <br><br>
    <?php if (isset($component)) { $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\HeaderSectionPage::class, ['title' => 'Struktur Organisasi  '.e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia').'','breadcrumbHome' => 'Home','breadcrumbCurrent' => 'Struktur Organisasi']); ?>
<?php $component->withName('header-section-page'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>
<?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df)): ?>
<?php $component = $__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df; ?>
<?php unset($__componentOriginal5de6c61179b5c431782cc0aa46c5056175d068df); ?>
<?php endif; ?>

    <div data-aos="fade-up" class=" py-16 mt-8 ">
        <div data-aos="fade-up" class="container mx-auto px-4 lg:px-20">

            <!-- Image Section -->
            

            <div style="min-width: 50%;" class="col-md-12 col-sm-6 col-xs-12">
                <p>
                <ol class="custom-counter">
                    <li><b>Ketua</b> : Dadan Nurdin, S.Ag, M.Si</li>
                    <li><b>Wakil Ketua</b> : Drs. H. Darya, M.Pd</li>
                    <li><b>Ketua Prodi Ekonomi Syariah</b> : Helmi Saftarijan, S.Hum, M.Pd.I</li>
                    <li><b>Ketua Prodi Akuntansi Syariah</b> : Ashhabul Kahfi, S.Pd.I, M.Pd</li>
                    <li><b>Ketua Prodi Perbankan Syariah</b> : Khaerul Mu’min, S.Pd, M.Pd</li>
                    <li><b>Kepala Akademik</b> : Yulianti Ika Susilawati, S.Pd, M.Pd</li>
                    <li><b>Kepala LPPM </b> : E. Haodudin Nurkifli, ST, M.Cs, P.hD</li>
                    <li><b>Kepala BPM </b> : Dany Ramdhany, MM</li>
                    <li><b>Kepala Unit Bisnis </b> : Ridwan Alamsyah, S.H, M.H</li>
                </ol>
                <hr>
                </p>
            </div>

            <!-- Description Section -->
            <div data-aos="fade-up"
                class="mt-12 text-center px md:px-[300px] space-y-4 flex justify-center items-center flex-col">
                <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
                <p data-aos="fade-up" class="text-gray-700 font-dmsans leading-relaxed text-center ">
                    Bersama <?php echo e($settings['nama kampus'] ?? 'Nama kampus tidak tersedia'); ?>, jadilah pribadi unggul yang siap
                    menaklukkan tantangan dunia dengan pengetahuan dan keterampilan terbaik!
                </p>
                <?php if (isset($component)) { $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940 = $component; } ?>
<?php $component = $__env->getContainer()->make(App\View\Components\Button::class, ['url' => '/pendaftaran']); ?>
<?php $component->withName('button'); ?>
<?php if ($component->shouldRender()): ?>
<?php $__env->startComponent($component->resolveView(), $component->data()); ?>
<?php $component->withAttributes([]); ?>DAFTAR SEKARANG <?php echo $__env->renderComponent(); ?>
<?php endif; ?>
<?php if (isset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940)): ?>
<?php $component = $__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940; ?>
<?php unset($__componentOriginal065ae5da12ba8e75c6b4e84d90798c2fb812b940); ?>
<?php endif; ?>
            </div>
        </div>
    </div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('Frontend.Layouts.app2', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /home/edunesiaserver/public_html/K2/WEB_KAMPUS/WEB_TEMPLATE/Ijo-Kuning/resources/views/Frontend/struktur.blade.php ENDPATH**/ ?>