@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
    <br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}"
        breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
                STEI Bina Cipta Madani berdiri pada tahun 2013 bedasarkan SK Dirjen Pendidikan Islam nomor 380 tahun 2013,
                saat ini memiiki 3 (tiga) program studi jenjang sarjana (S1) yaitu Ekonomi Syariah, Akuntansi Syariah dan
                Perbankan Syariah. STEI Bina Cipta Madani sebagai perguruan tinggi secara institusi sudah terakreditasi BAIK
                berdasarkan SK BAN-PT nomor 848/SK/BAN-PT/Ak/PT/IX/2022. Program studi Akuntansi Syariah sudah terakreditasi
                BAIK berdasarkan SK BAN-PT nomor 2018/SK/BAN-PT/Ak/S/V/2023, Program studi Ekonomi Syariah sudah
                terakreditasi C berdasarkan SK BAN-PT nomor 4445/SK/BAN-PT/Akred/S/XI/2017 dan sedang dalam proses pengajuan
                reakreditasi ke LAMEMBA, dan program studi Perbankan Syariah baru melakukan penerimaan mahasiswa baru tahun
                2023.
            </p>


        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
            </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
                Bergabunglah bersama {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan,
                Bentuk Karakter, Jadilah Pembawa Perubahan!
            </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
